/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "UCQToolBar.h"

/**
 * \brief Initialize the toolbar with the actions.
 *
 * \param parent Pointer to the parent QWidget.
 */
UCQToolBar::UCQToolBar ( QWidget* parent ) :
    QToolBar ( parent )
{
    QIcon loadTableActionIcon ( ":icons/document-open-uc.svg" );
    QIcon loadBlocksTableActionIcon ( ":icons/document-open-b.svg" );
    QIcon saveActionIcon ( ":icons/document-save.svg" );

    loadTableAction_       = new QAction ( loadTableActionIcon, "", this     );
    loadBlocksTableAction_ = new QAction (loadBlocksTableActionIcon, "", this);
    saveTableAction_       = new QAction ( saveActionIcon, "", this          );

    loadTableAction_->setToolTip       ( tr ( "Load Unicode Table"   ) );
    loadBlocksTableAction_->setToolTip ( tr ( "Load Block Table"     ) );
    saveTableAction_->setToolTip       ( tr ( "Export Unicode Table" ) );

    addAction ( loadTableAction_       );
    addAction ( loadBlocksTableAction_ );
    addAction ( saveTableAction_       );

    connect ( loadTableAction_, SIGNAL ( triggered ()        ),
              this,             SIGNAL ( loadTablePressed () ) );

    connect ( loadBlocksTableAction_, SIGNAL ( triggered ()              ),
              this,                   SIGNAL ( loadBlocksTablePressed () ) );

    connect ( saveTableAction_, SIGNAL ( triggered ()        ),
              this,             SIGNAL ( saveTablePressed () ) );
}

/**
 * \brief En-/Disable the Save Table action.
 *
 * \param enable If true the action is enabled, else disabled.
 *
 * \see MainWindow::updateStates()
 */
void UCQToolBar::enableSaveAction ( bool enable )
{
    saveTableAction_->setEnabled ( enable );
}
